==> touhoulittlemaid-fabric-1.20.1-0.1.2-forge1.3.7-sources.jar: com/github/tartaricacid/touhoulittlemaid/inventory/container/backpack/CraftingTableBackpackContainer.java <==
package com.github.tartaricacid.touhoulittlemaid.inventory.container.backpack;

import cn.sh1rocu.touhoulittlemaid.util.itemhandler.IItemHandler;
import cn.sh1rocu.touhoulittlemaid.util.itemhandler.SlotItemHandler;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.MaidMainContainer;
import net.fabricmc.fabric.api.screenhandler.v1.ExtendedScreenHandlerType;
import net.minecraft.class_1263;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1703;
import net.minecraft.class_1715;
import net.minecraft.class_1731;
import net.minecraft.class_1734;
import net.minecraft.class_1735;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2653;
import net.minecraft.class_3222;
import net.minecraft.class_3914;
import net.minecraft.class_3917;
import net.minecraft.class_3955;
import net.minecraft.class_3956;
import net.minecraft.class_8566;
import net.minecraft.world.inventory.*;
import java.util.Optional;

public class CraftingTableBackpackContainer extends MaidMainContainer {
    public static final class_3917<CraftingTableBackpackContainer> TYPE = new ExtendedScreenHandlerType<>(
            (id, inv, data) -> new CraftingTableBackpackContainer(id, inv, data.readInt())
    );
    private final class_8566 craftSlots = new class_1715(this, 3, 3);
    private final class_1731 resultSlots = new class_1731();
    private final class_3914 access;
    private final class_1734 resultSlot;
    private final class_1657 player;

    public CraftingTableBackpackContainer(int id, class_1661 inventory, int entityId) {
        super(TYPE, id, inventory, entityId);
        this.player = inventory.field_7546;
        this.access = class_3914.method_17392(this.getMaid().field_6002, this.getMaid().method_24515());
        this.resultSlot = new class_1734(this.player, this.craftSlots, this.resultSlots, 0, 229, 119);
        this.method_7621(this.resultSlot);
        for (int i = 0; i < 3; ++i) {
            for (int j = 0; j < 3; ++j) {
                this.method_7621(new class_1735(this.craftSlots, j + i * 3, 152 + j * 18, 101 + i * 18));
            }
        }
    }

    @Override
    public void method_7609(class_1263 container) {
        this.access.method_17393((level, blockPos) -> slotChangedCraftingGrid(this, level, this.player, this.craftSlots, this.resultSlots));
    }

    @Override
    public void method_7595(class_1657 player) {
        super.method_7595(player);
        this.access.method_17393((level, blockPos) -> this.method_7607(player, this.craftSlots));
    }

    @Override
    public boolean method_7613(class_1799 stack, class_1735 slot) {
        return slot.field_7871 != this.resultSlots && super.method_7613(stack, slot);
    }

    @Override
    public class_1799 method_7601(class_1657 player, int index) {
        class_1799 stack1 = class_1799.field_8037;
        class_1735 slot = this.field_7761.get(index);
        if (slot != null && slot.method_7681()) {
            class_1799 stack2 = slot.method_7677();
            stack1 = stack2.method_7972();
            if (index == resultSlot.field_7874) {
                this.access.method_17393((level, blockPos) -> stack2.method_7909().method_7843(stack2, level, player));
                if (!this.method_7616(stack2, 0, PLAYER_INVENTORY_SIZE, true)) {
                    return class_1799.field_8037;
                }
                slot.method_7670(stack2, stack1);
            } else if (index < resultSlot.field_7874) {
                if (index < PLAYER_INVENTORY_SIZE) {
                    if (!this.method_7616(stack2, PLAYER_INVENTORY_SIZE, resultSlot.field_7874, false)) {
                        return class_1799.field_8037;
                    }
                } else if (!this.method_7616(stack2, 0, PLAYER_INVENTORY_SIZE, true)) {
                    return class_1799.field_8037;
                }
            } else if (!this.method_7616(stack2, 0, PLAYER_INVENTORY_SIZE, false)) {
                return class_1799.field_8037;
            }
            if (stack2.method_7960()) {
                slot.method_48931(class_1799.field_8037);
            } else {
                slot.method_7668();
            }
            if (stack2.method_7947() == stack1.method_7947()) {
                return class_1799.field_8037;
            }
            slot.method_7667(player, stack2);
            if (index == resultSlot.field_7874) {
                player.method_7328(stack2, false);
            }
        }
        return stack1;
    }

    @Override
    protected void addBackpackInv(class_1661 inventory) {
        IItemHandler itemHandler = maid.getMaidInv();
        for (int i = 0; i < 6; i++) {
            method_7621(new SlotItemHandler(itemHandler, 6 + i, 143 + 18 * i, 57));
        }
        for (int i = 0; i < 6; i++) {
            method_7621(new SlotItemHandler(itemHandler, 12 + i, 143 + 18 * i, 75));
        }
    }

    private void slotChangedCraftingGrid(class_1703 menu, class_1937 level, class_1657 player, class_8566 container, class_1731 result) {
        if (!level.field_9236 && level.method_8503() != null) {
            class_3222 serverPlayer = (class_3222) player;
            class_1799 stack1 = class_1799.field_8037;
            Optional<class_3955> optional = level.method_8503().method_3772().method_8132(class_3956.field_17545, container, level);
            if (optional.isPresent()) {
                class_3955 recipe = optional.get();
                if (result.method_7665(level, serverPlayer, recipe)) {
                    class_1799 stack2 = recipe.method_8116(container, level.method_30349());
                    if (stack2.method_45435(level.method_45162())) {
                        stack1 = stack2;
                    }
                }
            }
            result.method_5447(0, stack1);
            menu.method_34245(0, stack1);
            serverPlayer.field_13987.method_14364(new class_2653(menu.field_7763, menu.method_37422(), resultSlot.field_7874, stack1));
        }
    }
}

==> touhoulittlemaid-fabric-1.20.1-0.4.0-forge1.4.5-sources.jar: com/github/tartaricacid/touhoulittlemaid/inventory/container/backpack/CraftingTableBackpackContainer.java <==
package com.github.tartaricacid.touhoulittlemaid.inventory.container.backpack;

import com.github.tartaricacid.touhoulittlemaid.api.backpack.ITriggerSlotChange;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.MaidMainContainer;
import net.fabricmc.fabric.api.screenhandler.v1.ExtendedScreenHandlerType;
import net.minecraft.class_1263;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1703;
import net.minecraft.class_1715;
import net.minecraft.class_1731;
import net.minecraft.class_1734;
import net.minecraft.class_1735;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2653;
import net.minecraft.class_3222;
import net.minecraft.class_3914;
import net.minecraft.class_3917;
import net.minecraft.class_3955;
import net.minecraft.class_3956;
import net.minecraft.class_8566;
import net.minecraft.world.inventory.*;
import java.util.Optional;

public class CraftingTableBackpackContainer extends MaidMainContainer {
    public static final class_3917<CraftingTableBackpackContainer> TYPE = new ExtendedScreenHandlerType<>(
            (id, inv, data) -> new CraftingTableBackpackContainer(id, inv, data.readInt())
    );
    private final class_8566 craftSlots = new class_1715(this, 3, 3);
    private final class_1731 resultSlots = new class_1731();
    private final class_3914 access;
    private final class_1734 resultSlot;
    private final class_1657 player;

    public CraftingTableBackpackContainer(int id, class_1661 inventory, int entityId) {
        super(TYPE, id, inventory, entityId);
        this.player = inventory.field_7546;
        this.access = class_3914.method_17392(this.getMaid().field_6002, this.getMaid().method_24515());
        this.resultSlot = new class_1734(this.player, this.craftSlots, this.resultSlots, 0, 229, 119);
        this.method_7621(this.resultSlot);
        for (int i = 0; i < 3; ++i) {
            for (int j = 0; j < 3; ++j) {
                this.method_7621(new class_1735(this.craftSlots, j + i * 3, 152 + j * 18, 101 + i * 18));
            }
        }
    }

    @Override
    public void method_7609(class_1263 container) {
        this.access.method_17393((level, blockPos) -> slotChangedCraftingGrid(this, level, this.player, this.craftSlots, this.resultSlots));
    }

    @Override
    public void method_7595(class_1657 player) {
        super.method_7595(player);
        this.access.method_17393((level, blockPos) -> this.method_7607(player, this.craftSlots));
    }

    @Override
    public boolean method_7613(class_1799 stack, class_1735 slot) {
        return slot.field_7871 != this.resultSlots && super.method_7613(stack, slot);
    }

    @Override
    public class_1799 method_7601(class_1657 player, int index) {
        class_1799 stack1 = class_1799.field_8037;
        class_1735 slot = this.field_7761.get(index);
        if (slot != null && slot.method_7681()) {
            class_1799 stack2 = slot.method_7677();
            stack1 = stack2.method_7972();
            if (index == resultSlot.field_7874) {
                this.access.method_17393((level, blockPos) -> stack2.method_7909().method_7843(stack2, level, player));
                if (!this.method_7616(stack2, 0, PLAYER_INVENTORY_SIZE, true)) {
                    return class_1799.field_8037;
                }
                slot.method_7670(stack2, stack1);
            } else if (index < resultSlot.field_7874) {
                if (index < PLAYER_INVENTORY_SIZE) {
                    if (!this.method_7616(stack2, PLAYER_INVENTORY_SIZE, resultSlot.field_7874, false)) {
                        return class_1799.field_8037;
                    }
                } else if (!this.method_7616(stack2, 0, PLAYER_INVENTORY_SIZE, true)) {
                    return class_1799.field_8037;
                }
            } else if (!this.method_7616(stack2, 0, PLAYER_INVENTORY_SIZE, false)) {
                return class_1799.field_8037;
            }
            if (stack2.method_7960()) {
                slot.method_48931(class_1799.field_8037);
            } else {
                slot.method_7668();
            }
            if (stack2.method_7947() == stack1.method_7947()) {
                return class_1799.field_8037;
            }
            slot.method_7667(player, stack2);
            // 触发 Shift 点击取出事件
            if (slot instanceof ITriggerSlotChange slotChange) {
                slotChange.onShiftTakeoff(player, stack1);
            }
            if (index == resultSlot.field_7874) {
                player.method_7328(stack2, false);
            }
        }
        return stack1;
    }

    @Override
    protected void addBackpackInv(class_1661 inventory) {
        for (int i = 0; i < 6; i++) {
            method_7621(new BackpackSlot(maid, 6 + i, 143 + 18 * i, 57));
        }
        for (int i = 0; i < 6; i++) {
            method_7621(new BackpackSlot(maid, 12 + i, 143 + 18 * i, 75));
        }
    }

    private void slotChangedCraftingGrid(class_1703 menu, class_1937 level, class_1657 player, class_8566 container, class_1731 result) {
        if (!level.field_9236 && level.method_8503() != null) {
            class_3222 serverPlayer = (class_3222) player;
            class_1799 stack1 = class_1799.field_8037;
            Optional<class_3955> optional = level.method_8503().method_3772().method_8132(class_3956.field_17545, container, level);
            if (optional.isPresent()) {
                class_3955 recipe = optional.get();
                if (result.method_7665(level, serverPlayer, recipe)) {
                    class_1799 stack2 = recipe.method_8116(container, level.method_30349());
                    if (stack2.method_45435(level.method_45162())) {
                        stack1 = stack2;
                    }
                }
            }
            result.method_5447(0, stack1);
            menu.method_34245(0, stack1);
            serverPlayer.field_13987.method_14364(new class_2653(menu.field_7763, menu.method_37422(), resultSlot.field_7874, stack1));
        }
    }
}
